@@ -3,7 +3,7 @@ package App::perlimports::Document;
 use Moo;
 use utf8;
 
-our $VERSION = '0.000047';
+our $VERSION = '0.000048';
 
 use App::perlimports::Annotations     ();
 use App::perlimports::ExportInspector ();
@@ -960,7 +960,7 @@ INCLUDE:
 
                 if ( $before ne $after ) {
                     $self->_warn_diff_for_linter(
-                        'import arguments have changed',
+                        'import arguments need tidying',
                         $include,
                         $include->content,
                         $elem->content
@@ -1110,7 +1110,7 @@ App::perlimports::Document - Make implicit imports explicit
 
 =head1 VERSION
 
-version 0.000047
+version 0.000048
 
 =head1 MOTIVATION
 
